# pyiron_lammps

[![Pipeline](https://github.com/pyiron/pyiron_lammps/actions/workflows/pipeline.yml/badge.svg)](https://github.com/pyiron/pyiron_lammps/actions/workflows/pipeline.yml)
[![codecov](https://codecov.io/gh/pyiron/pyiron_lammps/graph/badge.svg?token=OeZVIJ9vyW)](https://codecov.io/gh/pyiron/pyiron_lammps)

File based LAMMPS interface. Work in progress.